@@ -57,7 +57,7 @@ void set_nb(int fd);
 
 #define forceclose(fd) { while(0 != ::close(fd)) { if(errno != EINTR) break; }; fd=-1; }
 #define checkforceclose(fd) if(fd>=0){ while(0 != ::close(fd)) { if(errno != EINTR) break; }; fd=-1; }
-#define checkForceFclose(fh) if(fh) { int fd=fileno(fh); if(0!=::fclose(fh) && errno!=EBADF) forceclose(fd); fh=NULL;}
+#define checkForceFclose(fh) if(fh) { int fd=::fileno(fh); if(0!=::fclose(fh) && errno!=EBADF) forceclose(fd); fh=NULL;}
 
 
 
