@@ -60,7 +60,7 @@ public:
 	// returns when the state changes to complete or error
 	FiStatus WaitForFinish(int *httpCode=NULL);
 
-	bool SetupClean();
+	bool SetupClean(bool bForce=false);
 	
 	uint64_t m_nIncommingCount;
 	off_t m_nSizeSeen;
