@@ -43,7 +43,7 @@ tCacheMan::tCacheMan(int fd) :
 	m_nProgIdx(0), m_nProgTell(1), m_pDlcon(NULL)
 {
 	m_szDecoFile="maint.html";
-	m_gMaintTimeNow=time(NULL);
+	m_gMaintTimeNow=GetTime();
 
 }
 
@@ -643,31 +643,34 @@ bool tCacheMan::PatchFile(const string &srcRel,
 class fakeCon : public ::tCacheMan::tGetItemDelegate
 {
    public:
-      cmstring & sTempDataRel, &sReferencePathRel;
-      off_t nGotSize;
-      fakeCon(cmstring & a, cmstring &b) : sTempDataRel(a), sReferencePathRel(b) {};
-      operator tFileItemPtr()
-      {
-         class tHeadOnlyStorage : public fileitem_with_storage
-         {
-            public:
-               fakeCon &m_parent;
-               tHeadOnlyStorage(fakeCon &p)
-                  : fileitem_with_storage(p.sTempDataRel) // storage ref to physical data file
-                    , m_parent(p)
-            {
-               m_bAllowStoreData=false;
-               m_bHeadOnly=true;
-               m_head.LoadFromFile(SABSPATH(p.sReferencePathRel+".head"));
-            }
-               void Unreg()
-               {
-                  m_head.StoreToFile(m_sPathAbs+".head");
-                  m_parent.nGotSize = atoofft(m_head.h[header::CONTENT_LENGTH], -17);
-               };
-         };
-         return tFileItemPtr(static_cast<fileitem_base*>(new tHeadOnlyStorage(*this)));
-      }
+	cmstring & sTempDataRel, &sReferencePathRel;
+	off_t nGotSize;
+	fakeCon(cmstring & a, cmstring &b) :
+			sTempDataRel(a), sReferencePathRel(b)
+	{
+	}
+	operator tFileItemPtr()
+	{
+		class tHeadOnlyStorage: public fileitem_with_storage
+		{
+		public:
+			fakeCon &m_parent;
+			tHeadOnlyStorage(fakeCon &p) :
+					fileitem_with_storage(p.sTempDataRel) // storage ref to physical data file
+							, m_parent(p)
+			{
+				m_bAllowStoreData = false;
+				m_bHeadOnly = true;
+				m_head.LoadFromFile(SABSPATH(p.sReferencePathRel+".head"));
+			}
+			void Unreg()
+			{
+				m_head.StoreToFile(m_sPathAbs + ".head");
+				m_parent.nGotSize = atoofft(m_head.h[header::CONTENT_LENGTH], -17);
+			}
+		};
+		return tFileItemPtr(static_cast<fileitem_base*>(new tHeadOnlyStorage(*this)));
+	}
 };
 
 bool tCacheMan::GetAndCheckHead(cmstring & sTempDataRel, cmstring &sReferencePathRel,
