@@ -174,7 +174,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry, bool bUnpackForCsu
 				{
 					SendFmt() << "<font color=orange>BAD: " << sPathRel
 							<< " (truncating)</font><br>\n";
-					::truncate(sPathAbs.c_str(), 0);
+					ignore_value(::truncate(sPathAbs.c_str(), 0));
 				}
 				else
 				{
