@@ -286,13 +286,21 @@ bool fileitem_base::CheckUsableRange_unlocked(off_t nRangeLastByte)
 			&& atoofft(m_head.h[header::CONTENT_LENGTH], -255) > nRangeLastByte);
 }
 
-bool fileitem_base::SetupClean()
+bool fileitem_base::SetupClean(bool bForce)
 {
 	setLockGuard;
 
-	if(m_status>FIST_FRESH)
-		return false;
-	m_status=FIST_INITED;
+	if(bForce)
+	{
+		if(m_status>FIST_FRESH)
+			m_status = FIST_LOCALERROR;
+	}
+	else
+	{
+		if(m_status>FIST_FRESH)
+			return false;
+		m_status=FIST_INITED;
+	}
 	if(::truncate(m_sPathAbs.c_str(), 0) || ::truncate((m_sPathAbs+".head").c_str(), 0))
 		return false;
 
@@ -325,7 +333,7 @@ bool fileitem_with_storage::DownloadStartedStoreHeader(const header & h, const c
 		m_status=FIST_DLGOTHEAD; // assume that for now, may become error state...
 	
 	if(m_bCheckFreshness)
-		m_nTimeExpireAt = time(0) + MAXTEMPDELAY;
+		m_nTimeExpireAt = GetTime() + MAXTEMPDELAY;
 
 	m_nIncommingCount+=h.m_nEstimLength;
 
@@ -687,8 +695,8 @@ tFileItemPtr fileitem::GetRegisteredFileItem(MYSTD::string sPathKey)
 	MYCATCH(MYSTD::bad_alloc&)
 	{
 		p.reset();
-		return p;
 	}
+	return p;
 }
 
 bool fileitem::RegisterFileItem(SHARED_PTR<fileitem> spCustomFileItem)
@@ -715,7 +723,7 @@ void fileitem::UnregOneASAP(tFileItemPtr pItem)
 	if (!pItem)
 		return;
 	// download never started or no delayed expiration needed -> release now. Or expired long ago.
-	if (!pItem->m_nTimeExpireAt || time(0) >= pItem->m_nTimeExpireAt)
+	if (!pItem->m_nTimeExpireAt || GetTime() >= pItem->m_nTimeExpireAt)
 	{
 		pItem->Unreg();
 		return;
@@ -745,7 +753,7 @@ time_t fileitem::DoDelayedUnregAndCheck()
 	lockguard lockGlobalMap(mapLck);
 	MYMAP<string, tFileRefEntry>::iterator it, here;
 
-	time_t now=time(0);
+	time_t now=GetTime();
 
 	if(now<m_nEarliestExpiration) // unreachable anyhow
 		return m_nEarliestExpiration;
