@@ -23,6 +23,12 @@ using namespace MYSTD;
 // XXX no longer needed after debug logging overhaul
 #define REPLEVEL (m_type==rechecks::FILE_INDEX ? 4 : (m_type==rechecks::FILE_PKG ? 5 : SPAMLEVEL))
 
+#if 0 // defined(DEBUG)
+#define CHUNKDEFAULT true
+#warning testing chunk mode
+#else
+#define CHUNKDEFAULT false
+#endif
 
 #define SPECIAL_FD -42
 inline bool IsValidFD(int fd) { return fd>=0 || SPECIAL_FD == fd; }
@@ -230,8 +236,7 @@ ssize_t sendfile_generic(int out_fd, int in_fd, off_t *offset, size_t count)
 job::job(header *h, con *pParent) :
 	m_filefd(-1),
 	m_pParentCon(pParent),
-	m_bChunkMode(false),
-	//m_bCloseCon(false),
+	m_bChunkMode(CHUNKDEFAULT),
 	m_bIsHttp11(false),
 	m_bNoDownloadStarted(false),
 	m_state(STATE_SEND_MAIN_HEAD),
@@ -1031,10 +1036,10 @@ inline const char * job::BuildAndEnqueHeader(const FiStatus &fistate,
 	int httpstatus = respHead.getStatus();
 	LOG("State: " << httpstatus);
 
-	// nothing to send for special codes (not-unmodified&co.) or zero length bodies
+	// nothing to send for special codes (like not-unmodified) or w/ GUARANTEED empty body
 	bool bHasSendableData = !BODYFREECODE(httpstatus)
-			&& atoofft(respHead.h[header::CONTENT_LENGTH], 0);
-	// if that's a status for object with body but contlen is missing -> use chunked mode later
+			&& (!respHead.h[header::CONTENT_LENGTH] // not set, maybe chunked data
+			                || atoofft(respHead.h[header::CONTENT_LENGTH])); // set, to non-0
 
 	tSS &sb=m_sendbuf;
 	sb.clear();
@@ -1045,7 +1050,11 @@ inline const char * job::BuildAndEnqueHeader(const FiStatus &fistate,
 	if(bHasSendableData)
 	{
 		LOG("has sendable content");
-		if( ! respHead.h[header::CONTENT_LENGTH])
+		if( ! respHead.h[header::CONTENT_LENGTH]
+#ifdef DEBUG // might have been defined before for testing purposes
+		                 || m_bChunkMode
+#endif
+				)
 		{
 			// unknown length but must have data, will have to improvise: prepare chunked transfer
 			if ( ! m_bIsHttp11 ) // you cannot process this? go away
